@@ -138,7 +138,8 @@ class PowerMaxData(object):
                          'is_multipath': True,
                          'array': array,
                          'controller': {'host': '10.00.00.00'},
-                         'hostlunid': 3}
+                         'hostlunid': 3,
+                         'device_id': device_id}
     iscsi_device_info_metro = deepcopy(iscsi_device_info)
     iscsi_device_info_metro['metro_ip_and_iqn'] = [{'ip': ip2, 'iqn': iqn2}]
     iscsi_device_info_metro['metro_hostlunid'] = 2
@@ -1273,7 +1274,7 @@ class PowerMaxData(object):
 
     data_dict = {volume_id: volume_info_dict}
     platform = 'Linux-4.4.0-104-generic-x86_64-with-Ubuntu-16.04-xenial'
-    unisphere_version = u'V9.1.0.14'
+    unisphere_version = u'V9.1.0.17'
     unisphere_version_90 = "V9.0.0.1"
     openstack_release = '12.0.0.0b3.dev401'
     openstack_version = '12.0.0'
@@ -1522,3 +1523,13 @@ class PowerMaxData(object):
                       'Emulation': 'FBA',
                       'Configuration': 'TDEV',
                       'CompressionDisabled': False}})
+    staging_sg = 'STG-myhostB-4732de9b-98a4-4b6d-ae4b-3cafb3d34220-SG'
+    staging_mv1 = 'STG-myhostA-4732de9b-98a4-4b6d-ae4b-3cafb3d34220-MV'
+    staging_mv2 = 'STG-myhostB-4732de9b-98a4-4b6d-ae4b-3cafb3d34220-MV'
+    staging_mvs = [staging_mv1, staging_mv2]
+    legacy_mv1 = 'OS-myhostA-No_SLO-e14f48b8-MV'
+    legacy_mv2 = 'OS-myhostB-No_SLO-e14f48b8-MV'
+    legacy_shared_sg = 'OS-myhostA-No_SLO-SG'
+    legacy_mvs = [legacy_mv1, legacy_mv2]
+    legacy_not_shared_mv = 'OS-myhostA-SRP_1-Diamond-NONE-MV'
+    legacy_not_shared_sg = 'OS-myhostA-SRP_1-Diamond-NONE-SG'
