@@ -256,10 +256,13 @@ class RemoteFsSnapDriverTestCase(test.TestCase):
                  mock.call(*command3, run_as_root=True)]
         self._driver._execute.assert_has_calls(calls)
 
-    def _test_create_snapshot(self, volume_in_use=False, tmp_snap=False):
+    def _test_create_snapshot(self, volume_in_use=False, tmp_snap=False,
+                              display_name=None):
         fake_snapshot_info = {}
         fake_snapshot_file_name = os.path.basename(self._fake_snapshot_path)
 
+        snapshot = self._fake_snapshot
+        snapshot.display_name = display_name
         self._driver._local_path_volume_info = mock.Mock(
             return_value=mock.sentinel.fake_info_path)
         self._driver._read_info_file = mock.Mock(
@@ -278,18 +281,15 @@ class RemoteFsSnapDriverTestCase(test.TestCase):
             self._fake_snapshot.id: fake_snapshot_file_name
         }
         exp_acceptable_states = ['available', 'in-use', 'backing-up']
-        if tmp_snap:
+        if display_name and display_name.startswith('tmp-snap-'):
             exp_acceptable_states.append('downloading')
             self._fake_snapshot.volume.status = 'downloading'
-            display_name = 'tmp-snap-%s' % self._fake_snapshot.id
-            self._fake_snapshot.display_name = display_name
 
         if volume_in_use:
             self._fake_snapshot.volume.status = 'backing-up'
             self._fake_snapshot.volume.attach_status = 'attached'
             expected_method_called = '_create_snapshot_online'
         else:
-            self._fake_snapshot.volume.status = 'available'
             expected_method_called = '_do_create_snapshot'
 
         self._driver._create_snapshot(self._fake_snapshot)
@@ -317,8 +317,9 @@ class RemoteFsSnapDriverTestCase(test.TestCase):
                           self._driver._create_snapshot,
                           self._fake_snapshot)
 
-    def test_create_snapshot_w_image_caching(self):
-        self._test_create_snapshot(tmp_snap=True)
+    @ddt.data(None, 'test', 'tmp-snap-404f-404')
+    def test_create_snapshot_names(self, display_name):
+        self._test_create_snapshot(display_name=display_name)
 
     @mock.patch('cinder.db.snapshot_get')
     @mock.patch('time.sleep')
