@@ -255,6 +255,7 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
         self._is_replication_enabled = False
         self._replication_targets = []
         self._target_names = []
+        self._clone_v2_api_checked = False
 
         if self.rbd is not None:
             self.RBD_FEATURE_LAYERING = self.rbd.RBD_FEATURE_LAYERING
@@ -277,6 +278,22 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
             'max_over_subscription_ratio', 'volume_dd_blocksize')
         return RBD_OPTS + additional_opts
 
+    def _show_msg_check_clone_v2_api(self, volume_name):
+        if not self._clone_v2_api_checked:
+            self._clone_v2_api_checked = True
+            with RBDVolumeProxy(self, volume_name) as volume:
+                try:
+                    if (volume.volume.op_features() &
+                            self.rbd.RBD_OPERATION_FEATURE_CLONE_PARENT):
+                        LOG.info('Using v2 Clone API')
+                        return
+                except AttributeError:
+                    pass
+                LOG.warning('Not using v2 clone API, please upgrade to'
+                            ' mimic+ and set the OSD minimum client'
+                            ' compat version to mimic for better'
+                            ' performance, fewer deletion issues')
+
     def _get_target_config(self, target_id):
         """Get a replication target from known replication targets."""
         for target in self._replication_targets:
@@ -533,14 +550,14 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
 
         with RADOSClient(self) as client:
             ret, df_outbuf, __ = client.cluster.mon_command(
-                '{"prefix":"df", "format":"json"}', '')
+                '{"prefix":"df", "format":"json"}', b'')
             if ret:
                 LOG.warning('Unable to get rados pool stats.')
                 return 'unknown', 'unknown'
 
             ret, quota_outbuf, __ = client.cluster.mon_command(
                 '{"prefix":"osd pool get-quota", "pool": "%s",'
-                ' "format":"json"}' % pool_name, '')
+                ' "format":"json"}' % pool_name, b'')
             if ret:
                 LOG.warning('Unable to get rados pool quotas.')
                 return 'unknown', 'unknown'
@@ -1012,6 +1029,8 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
             self._flatten(self.configuration.rbd_pool, volume.name)
         if int(volume.size):
             self._resize(volume)
+
+        self._show_msg_check_clone_v2_api(snapshot.volume_name)
         return volume_update
 
     def _delete_backup_snaps(self, rbd_image):
@@ -1601,7 +1620,13 @@ class RBDDriver(driver.CloneableImageVD, driver.MigrateVD,
             if encrypted:
                 self._encrypt_image(context, volume, tmp_dir, tmp.name)
 
-            self.delete_volume(volume)
+            @utils.retry(exception.VolumeIsBusy,
+                         self.configuration.rados_connection_interval,
+                         self.configuration.rados_connection_retries)
+            def _delete_volume(volume):
+                self.delete_volume(volume)
+
+            _delete_volume(volume)
 
             chunk_size = self.configuration.rbd_store_chunk_size * units.Mi
             order = int(math.log(chunk_size, 2))
