@@ -498,7 +498,7 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
         new_key_id = volume_utils.create_encryption_key(context,
                                                         keymgr,
                                                         volume.volume_type_id)
-        new_key = keymgr.get(context, encryption['encryption_key_id'])
+        new_key = keymgr.get(context, new_key_id)
         new_pass = binascii.hexlify(new_key.get_encoded()).decode('utf-8')
 
         return (source_pass, new_pass, new_key_id)
@@ -559,6 +559,7 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
                     'cryptsetup',
                     'luksChangeKey',
                     attach_info['device']['path'],
+                    '--force-password',
                     run_as_root=True,
                     process_input=key_str,
                     log_errors=processutils.LOG_ALL_ERRORS)
@@ -583,6 +584,7 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
                     'cryptsetup',
                     '--batch-mode',
                     'luksFormat',
+                    '--force-password',
                     '--type', encryption['provider'],
                     '--cipher', encryption['cipher'],
                     '--key-size', str(encryption['key_size']),
@@ -772,6 +774,14 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
                     cache_entry['volume_id']
                 )
                 return model_update, True
+        except exception.SnapshotLimitReached:
+            # If this exception occurred when cloning the image-volume,
+            # it is because the image-volume reached its snapshot limit.
+            # Delete current cache entry and create a "fresh" entry
+            # NOTE: This will not delete the existing image-volume and
+            # only delete the cache entry
+            with excutils.save_and_reraise_exception():
+                self.image_volume_cache.evict(context, cache_entry)
         except NotImplementedError:
             LOG.warning('Backend does not support creating image-volume '
                         'clone. Image will be downloaded from Glance.')
@@ -855,17 +865,18 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
                         image_id,
                         image_meta
                     )
+                except exception.SnapshotLimitReached:
+                    # This exception will be handled by the caller's
+                    # (_create_from_image) retry decorator
+                    with excutils.save_and_reraise_exception():
+                        LOG.debug("Snapshot limit reached. Creating new "
+                                  "image-volume.")
                 except exception.CinderException as e:
                     LOG.warning('Failed to create volume from image-volume '
                                 'cache, image will be downloaded from Glance. '
                                 'Error: %(exception)s',
                                 {'exception': e})
 
-                    # If an exception occurred when cloning the image-volume,
-                    # it may be the image-volume reached its snapshot limit.
-                    # Create another "fresh" cache entry.
-                    update_cache = True
-
                 # Don't cache unless directed.
                 if not cloned and update_cache:
                     should_create_cache_entry = True
@@ -957,6 +968,7 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
 
         return model_update
 
+    @utils.retry(exception.SnapshotLimitReached, retries=1)
     def _create_from_image(self, context, volume,
                            image_location, image_id, image_meta,
                            image_service, **kwargs):
